@@ -23,14 +23,15 @@
 #include <speller.h>
 #include "ui_debug.h"
 
-namespace Sonnet
-{
-
+namespace Sonnet {
 //@cond PRIVATE
 class DictionaryComboBoxPrivate
 {
 public:
-    explicit DictionaryComboBoxPrivate(DictionaryComboBox *combo) : q(combo) {}
+    explicit DictionaryComboBoxPrivate(DictionaryComboBox *combo) : q(combo)
+    {
+    }
+
     DictionaryComboBox *q;
     void slotDictionaryChanged(int idx);
 };
@@ -40,10 +41,12 @@ void DictionaryComboBoxPrivate::slotDictionaryChanged(int idx)
     emit q->dictionaryChanged(q->itemData(idx).toString());
     emit q->dictionaryNameChanged(q->itemText(idx));
 }
+
 //@endcon
 
 DictionaryComboBox::DictionaryComboBox(QWidget *parent)
-    : QComboBox(parent), d(new DictionaryComboBoxPrivate(this))
+    : QComboBox(parent)
+    , d(new DictionaryComboBoxPrivate(this))
 {
     reloadCombo();
     connect(this, SIGNAL(activated(int)),
@@ -89,9 +92,12 @@ void DictionaryComboBox::setCurrentByDictionaryName(const QString &name)
 
 bool DictionaryComboBox::assignByDictionnary(const QString &dictionary)
 {
-    if (dictionary.isEmpty() || dictionary == itemData(currentIndex()).toString()) {
+    if (dictionary.isEmpty()) {
         return false;
     }
+    if (dictionary == itemData(currentIndex()).toString()) {
+        return true;
+    }
 
     int idx = findData(dictionary);
     if (idx == -1) {
@@ -112,16 +118,28 @@ void DictionaryComboBox::setCurrentByDictionary(const QString &dictionary)
 void DictionaryComboBox::reloadCombo()
 {
     clear();
-    Sonnet::Speller *speller = new Sonnet::Speller();
-    QMap<QString, QString> dictionaries = speller->availableDictionaries();
-    QMapIterator<QString, QString> i(dictionaries);
+    Sonnet::Speller speller;
+    QMap<QString, QString> preferredDictionaries = speller.preferredDictionaries();
+    QMapIterator<QString, QString> i(preferredDictionaries);
     while (i.hasNext()) {
         i.next();
         addItem(i.key(), i.value());
     }
-    delete speller;
+    if (count()) {
+        insertSeparator(count());
+    }
+
+    QMap<QString, QString> dictionaries = speller.availableDictionaries();
+    i = dictionaries;
+    while (i.hasNext()) {
+        i.next();
+        if (preferredDictionaries.contains(i.key())) {
+            continue;
+        }
+        addItem(i.key(), i.value());
+    }
 }
 
-}
+} // namespace Sonnet
 
 #include "moc_dictionarycombobox.cpp"
